@@ -1,4 +1,4 @@
-from django.conf.urls import re_path
+from django.urls import re_path
 
 from .views import SettingsView, SignageHTMLView, SignagePNGView, SignageSVGView
 
